summaryrefslogtreecommitdiffstats
path: root/karm
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 19:12:32 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 19:12:32 -0600
commit9a8a1e372f4f35ebdc75da2a2cddc06a77e44fc4 (patch)
treefd03284328d7fbf88ace3e6c4ebe86c6a2d28ba5 /karm
parentf2a152bb4c76b5e29e782c5ecf49a2b44fdd87e5 (diff)
downloadtdepim-9a8a1e372f4f35ebdc75da2a2cddc06a77e44fc4.tar.gz
tdepim-9a8a1e372f4f35ebdc75da2a2cddc06a77e44fc4.zip
Rename KDEHOME and KDEDIR
Diffstat (limited to 'karm')
-rw-r--r--karm/test/locking.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/karm/test/locking.cpp b/karm/test/locking.cpp
index 2c18d4fed..cdf5e41a5 100644
--- a/karm/test/locking.cpp
+++ b/karm/test/locking.cpp
@@ -128,9 +128,9 @@ int main( int argc, char *argv[] )
short rval = 0;
// Use another directory than the real one, just to keep things clean
// KDEHOME needs to be writable though, for a ksycoca database
// FIXME: Delete this directory when done with test.
- setenv( "KDEHOME", TQFile::encodeName( TQDir::homeDirPath() + "/.kde-testresource" ), true );
+ setenv( "TDEHOME", TQFile::encodeName( TQDir::homeDirPath() + "/.kde-testresource" ), true );
// Copied from Till's test in libkcal. Not sure what this is for.
setenv( "KDE_FORK_SLAVES", "yes", true ); // simpler, for the final cleanup
@@ -128,9 +128,9 @@ int main( int argc, char *argv[] )
short rval = 0;
// Use another directory than the real one, just to keep things clean
- // KDEHOME needs to be writable though, for a ksycoca database
+ // TDEHOME needs to be writable though, for a ksycoca database
// FIXME: Delete this directory when done with test.